.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xshape
======

Defined in ``xtensor/xshape.hpp``

.. doxygenfunction:: bool same_shape(const S1& s1, const S2& s2)
   :project: xtensor

.. doxygenfunction:: bool has_shape(const E& e, std::initializer_list<S> shape)
   :project: xtensor

.. doxygenfunction:: bool has_shape(const E& e, const S& shape)
   :project: xtensor
